
clear all
set more off


***   directories
local dir = "...\replication"

**  The data used are from Autor, Manning, and Smith (2016)                          **
**   and downloadable from "https://www.aeaweb.org/articles?id=10.1257/app.20140073" **

***   minimum wage
use "`dir'\data\raw\minwage-by-state.dta", clear
g tmp=1
sort year state minw
by year state minw: egen count = count(tmp)
by year state     : egen max = max(count)
sort state year month
by state year: egen count2 = mean(count)
g newmin = minw if count==max & count2!=6
by state year: replace newmin=(minw+minw[_n-1])/2 if count==6 & month==7 & count[_n-1]==6 & month[_n-1]==6 & count2==6
drop count count2
sort state year
collapse (max) newmin, by(state year)
rename newmin minw
sort state year
drop if state==53
tempfile minw
sort state year
save "`dir'\data\mw.dta", replace


***   sample
forvalues t = 1979/2012 {
	* sample including non-employed
	use "`dir'\data\raw\morg_cleaned_`t'.dta", clear
	* sample selection
	keep if age>=18 & age<=64
	drop if hr_alloc==1 | (hourlyworker==0 & aernwk_flag==1)
	drop if (year>=1974&year<=1988&class==3) | (year>=1989&year<=1993&(class==5|class==6)) | (year>=1994&(class==6|class==7))
	replace hr_wage =. if hr_wage<=0
	drop if state==53 /* DC */
	if year<=1988 keep if mlr==1|mlr==3|mlr==4|mlr==5|mlr==7 /* employed (at work) & unemployed & not in labor force */
	if year>=1989 keep if mlr==1|mlr==3|mlr==4|mlr==5|mlr==6|mlr==7 /* employed (at work) & unemployed (on layoff & looking) & not in labor force */
	if year>=1994 keep if mlr==1|mlr==3|mlr==4|mlr==5|mlr==7 /* employed (at work) & unemployed (on layoff & looking) & not in labor force */
	drop if hr_wage==.&mlr==1 /* missing wages for employed */
	* variable construction
	g w  = hr_wage /* ernwkt/hours or ernhr */
	g s  = educomp
	g s2 = educomp^2
	g x  = exp
	g x2 = exp^2
	g g  = (sex==1)
	g       y = ernwkt
	replace y = 2885 if year>=1998 & year<=2012 & ernwkt>2884 & ernwkt<=2885
	g       h = hours
	replace y = w * h if hourlyworker==1 & ernhr!=. & ernhr>0 /* for hourly workers */
	g       ymax =  999 if year>=1973 & year<=1985
	replace ymax = 1999 if year>=1986 & year<=1988
	replace ymax = 1923 if year>=1989 & year<=1997
	replace ymax = 2885 if year>=1998 & year<=2012
	g       d = 0 if hourlyworker==0
	replace d = 1 if hourlyworker==1 | hr_wage==.
	keep state year w y h s s2 x x2 g wgt wgt_hrs ymax d gdp class mlr
	rename wgt wgt0
	rename wgt_hrs wgt
	g s_13    = (s>=13)
	g x_0_9   = (x>= 0 & x< 10)
	g x_10_19 = (x>=10 & x< 20)
	g x_20_29 = (x>=20 & x< 30)
	g x_30    = (x>=30)
	label drop _all
	lab var year  "survey year"
	lab var state "state code"
	lab var wgt0  "sampling weight"
	lab var wgt   "sampling weight * hours"
	lab var w     "hourly wage"
	lab var s     "yrs. schooling"
	lab var s2    "s^2"
	lab var x     "yrs. experience"
	lab var x2    "x^2"
	lab var g     "1:male 0:female"
	lab var y     "labor earnings"
	lab var h     "hours worked"
	lab var ymax  "threshold of labor earnings"
	lab var d     "1:hourly worker 0:otherwise"
	qui merge m:1 year state using "`dir'\data\mw.dta"
	lab var minw  "minimum wage, nominal"
	keep if _merge==3
	drop _merge
	order state year w s s2 x x2 g wgt minw ymax y h
	
	replace w = minw if w< minw /* assign minimum wages to workers who earn below the minimum wage */
	replace w = .    if h==0    /* assign missing wages to workers who work zero hours */
	g       topc  = ymax   /h  if d == 0 /* top-code values for monthly paid workers (d==0) */
	replace topc  = 10*ymax/h  if d == 1 /* top-code values for hourly paid workers (d==1) multiplied by 10 so that no one will be top-coded */
	* real, log
	g lnw   = log(w   *gdp)
	g lnmw  = log(minw*gdp)
	g lntop = log(topc*gdp)
	drop topc
	egen sid   = group(state) /* state id: 1-50 */ 
	g dc1 = (lnw<=lnmw)      /* =1 if censored due to minimum wage */
	g dc2 = (y>=ymax & d==0) /* =1 if censored due to top-coding for monthly paid workers */ 
	g d_miss = (w==.)
	label var w      "hourly wage: nominal, truncated at mw"
	label var lnw    "hourly wage: real, log"
	label var lnmw   "minimum wage: real, log"
	label var lntop  "top-coding threshold by individual: real, log"
	label var dc1    "1:censored at mw 0:otherwise"
	label var dc2    "1:top-coded 0:otherwise"
	label var d_miss "1:not working 0:working"
	sort sid
	
	g id = _n

	qui compress
	save "`dir'\data\sample_`t'.dta", replace
	
}
