
clear all
set more off
set scheme lean1
graph set eps fontface Times


* Figures 9, 11, 13, 15; 20 (D5), 21 (D6), 22 (D7), 23 (D8)


***   directories
local dir = "...\replication"


***  Actual changes in hourly wages
* evaluate by (s, x, g)
foreach s of numlist 12 16 {
	foreach x of numlist 0 5 10 25 {
		foreach g of numlist 0 1 {
		
			di "s=`s', x=`x', g=`g'"
			use "`dir'\data\est\step1_all.dta", clear
			sort state year
			qui keep if year==1979|year==1989|year==2012
			
			foreach Q of numlist 5 10 20 30 40 50 60 70 80 90 {
				qui g lnw_hat_q`Q' =  a0_q`Q' +  a1_q`Q'*`s' +  a2_q`Q'*`s'^2 +  a3_q`Q'*`x' +  a4_q`Q'*`x'^2 +  a5_q`Q'*`g'
				qui g Dlnw_q`Q' = lnw_hat_q`Q'- lnw_hat_q`Q'[_n-1] if state==state[_n-1]
			}
			qui keep if year==1989|year==2012
			
			* aggregate
			collapse Dlnw_q5 Dlnw_q10 Dlnw_q20 Dlnw_q30 Dlnw_q40 Dlnw_q50 Dlnw_q60 Dlnw_q70 Dlnw_q80 Dlnw_q90 [pw=sumwt], by(year)
			qui g s = `s'
			qui g x = `x'
			qui g g = `g'
			qui save "`dir'\data\actual\s`s'x`x'g`g'.dta", replace
		}
	}
}
* append
foreach s of numlist 12 16 {
	foreach x of numlist 0 5 10 25 {
		foreach g of numlist 0 1 {
			if `s'==12 & `x'==0 & `g'==0 {
				use "`dir'\data\actual\s`s'x`x'g`g'.dta", clear
			}
			else {
				append using "`dir'\data\actual\s`s'x`x'g`g'.dta"
			}
		}
	}
}
compress
aorder
keep year s x g Dlnw_q5-Dlnw_q90
order year s x g Dlnw_q5-Dlnw_q90
save "`dir'\data\actual\wagediff.dta", replace
* erase
foreach s of numlist 12 16 {
	foreach x of numlist 0 5 10 25 {
		foreach g of numlist 0 1 {
			erase "`dir'\data\actual\s`s'x`x'g`g'.dta"
		}
	}
}

***   Changes in between-group differentials
use "`dir'\data\actual\wagediff.dta", clear
reshape long Dlnw_q, i(year s x g) j(pct)
foreach a in Dlnw {
	rename `a'_q `a'_s
}
reshape wide Dlnw_s, i(year pct x g) j(s)
foreach a in Dlnw {
	foreach s of numlist 12 16 {
		rename `a'_s`s' `a'_s`s'_x
	}
}
reshape wide Dlnw_s12_x-Dlnw_s16_x, i(year pct g) j(x)
foreach a in Dlnw {
	foreach s of numlist 12 16 {
		foreach x of numlist 0 5 10 25 {
			rename `a'_s`s'_x`x' `a'_s`s'_x`x'_g
		}
	}
}
reshape wide Dlnw_s12_x0_g-Dlnw_s16_x25_g, i(year pct) j(g)
** educational wage differential
foreach x of numlist 0 5 10 25 {
	foreach g of numlist 0 1 {
		g Dlnw_s1612_x`x'_g`g' = 100*(Dlnw_s16_x`x'_g`g' - Dlnw_s12_x`x'_g`g')
	}
}
** experience wage differential
foreach s of numlist 12 16 {
	foreach g of numlist 0 1 {
		g Dlnw_s`s'_x2505_g`g' = 100*(Dlnw_s`s'_x25_g`g' - Dlnw_s`s'_x5_g`g')
	}
}
** gender wage differential
foreach s of numlist 12 16 {
	foreach x of numlist 0 5 10 25 {
		g Dlnw_s`s'_x`x'_g10 = 100*(Dlnw_s`s'_x`x'_g1 - Dlnw_s`s'_x`x'_g0)
	}
}
collapse Dlnw_s12_x0_g0-Dlnw_s16_x25_g10, by(year pct)
save "`dir'\data\actual\wagediff_bg.dta", replace


***   Changes in within-group differentials
use "`dir'\data\actual\wagediff.dta", clear
* 90-10, 50-10, 50-20
g Dlnw_q9010 = 100*(Dlnw_q90 - Dlnw_q10)
g Dlnw_q5010 = 100*(Dlnw_q50 - Dlnw_q10)
g Dlnw_q5020 = 100*(Dlnw_q50 - Dlnw_q20)
save "`dir'\data\actual\wagediff_wg.dta", replace


***   Actual and counterfactual changes, 1989-2012   ***
use "`dir'\data\est\wagediff_bg.dta", clear
merge 1:1 year pct using "`dir'\data\actual\wagediff_bg.dta"
drop _merge
keep if year==2012
**  educational wage differential
foreach x of numlist 0 5 10 25 {
	foreach g of numlist 0 1 {
		g Dlnw_cf_s1612_x`x'_g`g' = Dlnw_s1612_x`x'_g`g' - Dlnw_mw_s1612_x`x'_g`g'
	}
}
**  experience wage differential
foreach s of numlist 12 16 {
	foreach g of numlist 0 1 {
		g Dlnw_cf_s`s'_x2505_g`g' = Dlnw_s`s'_x2505_g`g' - Dlnw_mw_s`s'_x2505_g`g'
	}
}
**  gender wage differential
foreach s of numlist 12 16 {
	foreach x of numlist 0 5 10 25 {
		g Dlnw_cf_s`s'_x`x'_g10 = Dlnw_s`s'_x`x'_g10 - Dlnw_mw_s`s'_x`x'_g10
	}
}
keep if pct==5|pct==10|pct==20|pct==30|pct==40|pct==50|pct==60|pct==70|pct==80|pct==90
g decile = _n
lab def decile 1 ".05" 2 ".1" 3 ".2" 4 ".3" 5 ".4" 6 ".5" 7 ".6" 8 ".7" 9 ".8" 10 ".9"
label values decile decile
foreach x of numlist 5 10 {
	foreach g of numlist 0 1 {
		graph bar Dlnw_s1612_x`x'_g`g' Dlnw_cf_s1612_x`x'_g`g', over(decile, label(labsize(medium))) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ytitle("") ylabel(-5(5)25, grid glp(dot) labsize(medlarge)) b1title("Quantile", size(medium)) aspectratio(.75) scale(1.4) /*title("{it:exper} = `x', {it:male} = `g'")*/ graphregion(margin(zero))
		graph export "`dir'\figure\figure9_x`x'_g`g'.eps", as(eps) preview(off) replace
		graph export "`dir'\figure\figure9_x`x'_g`g'.jpg", as(jpg) quality(90) replace
	}
}
foreach s of numlist 12 16 {
	foreach g of numlist 0 1 {
		graph bar Dlnw_s`s'_x2505_g`g' Dlnw_cf_s`s'_x2505_g`g', over(decile, label(labsize(medium))) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ytitle("") ylabel(-10(5)20, grid glp(dot) labsize(medlarge)) b1title("Quantile", size(medium)) aspectratio(.75) scale(1.4) /*title("{it:educ} = `s', {it:male} = `g'")*/ graphregion(margin(zero))
		graph export "`dir'\figure\figure11_s`s'_g`g'.eps", as(eps) preview(off) replace
		graph export "`dir'\figure\figure11_s`s'_g`g'.jpg", as(jpg) quality(90) replace
	}
}
foreach s of numlist 12 16 {
	foreach x of numlist 5 10 {
		graph bar Dlnw_s`s'_x`x'_g10 Dlnw_cf_s`s'_x`x'_g10, over(decile, label(labsize(medium))) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ytitle("") ylabel(-20(5)10, grid glp(dot) labsize(medlarge)) b1title("Quantile", size(medium)) aspectratio(.75) scale(1.4) /*title("{it:educ} = `s', {it:exper} = `x'")*/ graphregion(margin(zero))
		graph export "`dir'\figure\figure13_s`s'_x`x'.eps", as(eps) preview(off) replace
		graph export "`dir'\figure\figure13_s`s'_x`x'.jpg", as(jpg) quality(90) replace
	}
}
***   Actual and counterfactual changes, 1979-1989   ***
use "`dir'\data\est\wagediff_bg.dta", clear
merge 1:1 year pct using "`dir'\data\actual\wagediff_bg.dta"
drop _merge
keep if year==1989
**  educational wage differential
foreach x of numlist 5 10 {
	foreach g of numlist 0 1 {
		g Dlnw_cf_s1612_x`x'_g`g' = Dlnw_s1612_x`x'_g`g' - Dlnw_mw_s1612_x`x'_g`g'
	}
}
**  experience wage differential
foreach s of numlist 12 16 {
	foreach g of numlist 0 1 {
		g Dlnw_cf_s`s'_x2505_g`g' = Dlnw_s`s'_x2505_g`g' - Dlnw_mw_s`s'_x2505_g`g'
	}
}
**  gender wage differential
foreach s of numlist 12 16 {
	foreach x of numlist 5 10 {
		g Dlnw_cf_s`s'_x`x'_g10 = Dlnw_s`s'_x`x'_g10 - Dlnw_mw_s`s'_x`x'_g10
	}
}
keep if pct==5|pct==10|pct==20|pct==30|pct==40|pct==50|pct==60|pct==70|pct==80|pct==90
g decile = _n
lab def decile 1 ".05" 2 ".1" 3 ".2" 4 ".3" 5 ".4" 6 ".5" 7 ".6" 8 ".7" 9 ".8" 10 ".9"
label values decile decile
foreach x of numlist 5 10 {
	foreach g of numlist 0 1 {
		graph bar Dlnw_s1612_x`x'_g`g' Dlnw_cf_s1612_x`x'_g`g', over(decile, label(labsize(medium))) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ytitle("") ylabel(-5(5)25, grid glp(dot) labsize(medlarge)) b1title("Quantile", size(medium)) aspectratio(.75) scale(1.4) /*title("{it:exper} = `x', {it:male} = `g'")*/ graphregion(margin(zero))
		graph export "`dir'\figure\figure20_x`x'_g`g'.eps", as(eps) preview(off) replace
		graph export "`dir'\figure\figure20_x`x'_g`g'.jpg", as(jpg) quality(90) replace
	}
}
foreach s of numlist 12 16 {
	foreach g of numlist 0 1 {
		graph bar Dlnw_s`s'_x2505_g`g' Dlnw_cf_s`s'_x2505_g`g', over(decile, label(labsize(medium))) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ytitle("") ylabel(-5(5)25, grid glp(dot) labsize(medlarge)) b1title("Quantile", size(medium)) aspectratio(.75) scale(1.4) /*title("{it:educ} = `s', {it:male} = `g'")*/ graphregion(margin(zero))
		graph export "`dir'\figure\figure21_s`s'_g`g'.eps", as(eps) preview(off) replace
		graph export "`dir'\figure\figure21_s`s'_g`g'.jpg", as(jpg) quality(90) replace
	}
}
foreach s of numlist 12 16 {
	foreach x of numlist 5 10 {
		graph bar Dlnw_s`s'_x`x'_g10 Dlnw_cf_s`s'_x`x'_g10, over(decile, label(labsize(medium))) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ytitle("") ylabel(-25(5)5, grid glp(dot) labsize(medlarge)) b1title("Quantile", size(medium)) aspectratio(.75) scale(1.4) /*title("{it:educ} = `s', {it:exper} = `x'")*/ graphregion(margin(zero))
		graph export "`dir'\figure\figure22_s`s'_x`x'.eps", as(eps) preview(off) replace
		graph export "`dir'\figure\figure22_s`s'_x`x'.jpg", as(jpg) quality(90) replace
	}
}


***   Within-group differentials, 1989-2012
use "`dir'\data\actual\wagediff_wg.dta", clear
merge 1:1 year s x g using "`dir'\data\est\wagediff_wg.dta"
drop _merge
keep if year==2012
* 90-10, 50-10, 50-20
g Dlnw_cf_q9010 = Dlnw_q9010 - Dlnw_mw_q9010
g Dlnw_cf_q5010 = Dlnw_q5010 - Dlnw_mw_q5010
g Dlnw_cf_q5020 = Dlnw_q5020 - Dlnw_mw_q5020
keep if x<15
**  males
preserve
keep if g==1
* 90-10
sort year s x
by year: g group = _n
foreach k of numlist 1/6 {
	local s`k' = s[`k']
	local x`k' = x[`k']
}
lab def group 1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')"
label values group group
graph bar Dlnw_q9010 Dlnw_cf_q9010, over(group/*, label(labsize(vsmall))*/) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ylabel(-25(5)10, grid glp(dot)) ytitle("") aspectratio(.75) scale(1.5) /*title("90-10, males")*/ graphregion(margin(zero))
graph export "`dir'\figure\figure15_9010_g1.eps", as(eps) preview(off) replace
graph export "`dir'\figure\figure15_9010_g1.jpg", as(jpg) quality(90) replace
drop group
label drop group
* 50-10, 50-20
foreach Q of numlist 10 20 {
	sort year s x
	by year: g group = _n
	foreach k of numlist 1/6 {
		local s`k' = s[`k']
		local x`k' = x[`k']
	}
	lab def group 1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')"
	label values group group
	graph bar Dlnw_q50`Q' Dlnw_cf_q50`Q', over(group/*, label(labsize(vsmall))*/) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ylabel(-25(5)10, grid glp(dot)) ytitle("") aspectratio(.75) scale(1.5) /* title("50-`Q', males")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure15_50`Q'_g1.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure15_50`Q'_g1.jpg", as(jpg) quality(90) replace
	drop group
	label drop group
}
**  females
restore
keep if g==0
* 90-10
sort year s x
by year: g group = _n
foreach k of numlist 1/6 {
	local s`k' = s[`k']
	local x`k' = x[`k']
}
lab def group 1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')"
label values group group
graph bar Dlnw_q9010 Dlnw_cf_q9010, over(group/*, label(labsize(vsmall))*/) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ylabel(-25(5)10, grid glp(dot)) ytitle("") aspectratio(.75) scale(1.5) /*title("90-10, females")*/ graphregion(margin(zero))
graph export "`dir'\figure\figure15_9010_g0.eps", as(eps) preview(off) replace
graph export "`dir'\figure\figure15_9010_g0.jpg", as(jpg) quality(90) replace
drop group
label drop group
* 50-10, 50-20
foreach Q of numlist 10 20 {
	sort year s x
	by year: g group = _n
	foreach k of numlist 1/6 {
		local s`k' = s[`k']
		local x`k' = x[`k']
	}
	lab def group 1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')"
	label values group group
	graph bar Dlnw_q50`Q' Dlnw_cf_q50`Q', over(group/*, label(labsize(vsmall))*/) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ylabel(-25(5)10, grid glp(dot)) ytitle("") aspectratio(.75) scale(1.5) /* title("50-`Q', females")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure15_50`Q'_g0.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure15_50`Q'_g0.jpg", as(jpg) quality(90) replace
	drop group
	label drop group
}
***   Within-group differentials, 1979-1989
use "`dir'\data\actual\wagediff_wg.dta", clear
merge 1:1 year s x g using "`dir'\data\est\wagediff_wg.dta"
drop _merge
keep if year==1989
* 90-10, 50-10, 50-20
g Dlnw_cf_q9010 = Dlnw_q9010 - Dlnw_mw_q9010
g Dlnw_cf_q5010 = Dlnw_q5010 - Dlnw_mw_q5010
g Dlnw_cf_q5020 = Dlnw_q5020 - Dlnw_mw_q5020
keep if x<15
**  males
preserve
keep if g==1
* 90-10
sort year s x
by year: g group = _n
foreach k of numlist 1/6 {
	local s`k' = s[`k']
	local x`k' = x[`k']
}
lab def group 1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')"
label values group group
graph bar Dlnw_q9010 Dlnw_cf_q9010, over(group/*, label(labsize(vsmall))*/) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ylabel(-10(5)25, grid glp(dot)) ytitle("") aspectratio(.75) scale(1.5) /*title("90-10, males")*/ graphregion(margin(zero))
graph export "`dir'\figure\figure23_9010_g1.eps", as(eps) preview(off) replace
graph export "`dir'\figure\figure23_9010_g1.jpg", as(jpg) quality(90) replace
drop group
label drop group
* 50-10, 50-20
foreach Q of numlist 10 20 {
	sort year s x
	by year: g group = _n
	foreach k of numlist 1/6 {
		local s`k' = s[`k']
		local x`k' = x[`k']
	}
	lab def group 1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')"
	label values group group
	graph bar Dlnw_q50`Q' Dlnw_cf_q50`Q', over(group/*, label(labsize(vsmall))*/) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ylabel(-10(5)25, grid glp(dot)) ytitle("") aspectratio(.75) scale(1.5) /* title("50-`Q', males")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure23_50`Q'_g1.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure23_50`Q'_g1.jpg", as(jpg) quality(90) replace
	drop group
	label drop group
}
**  females
restore
keep if g==0
* 90-10
sort year s x
by year: g group = _n
foreach k of numlist 1/6 {
	local s`k' = s[`k']
	local x`k' = x[`k']
}
lab def group 1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')"
label values group group
graph bar Dlnw_q9010 Dlnw_cf_q9010, over(group/*, label(labsize(vsmall))*/) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ylabel(-10(5)25, grid glp(dot)) ytitle("") aspectratio(.75) scale(1.5) /*title("90-10, females")*/ graphregion(margin(zero))
graph export "`dir'\figure\figure23_9010_g0.eps", as(eps) preview(off) replace
graph export "`dir'\figure\figure23_9010_g0.jpg", as(jpg) quality(90) replace
drop group
label drop group
* 50-10, 50-20
foreach Q of numlist 10 20 {
	sort year s x
	by year: g group = _n
	foreach k of numlist 1/6 {
		local s`k' = s[`k']
		local x`k' = x[`k']
	}
	lab def group 1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')"
	label values group group
	graph bar Dlnw_q50`Q' Dlnw_cf_q50`Q', over(group/*, label(labsize(vsmall))*/) bar(1, color(gs6)) bar(2, color(gs10)) legend(pos(6) row(1) lab(1 "Actual") lab(2 "Counterfactual")) ylabel(-10(5)25, grid glp(dot)) ytitle("") aspectratio(.75) scale(1.5) /* title("50-`Q', females")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure23_50`Q'_g0.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure23_50`Q'_g0.jpg", as(jpg) quality(90) replace
	drop group
	label drop group
}
