##=====================================================================
## Bootstrap: 1st stage   
## --------------------------------------------------------------------
## - Weighted boostrap for censored quantile regression 
##   for each state and time.
## - Given sample sizes, this process can be time-consuming. 
##   It is possible to run inside of loops parallelly by 
##   distributing the tasks over a computer cluster. 
##=====================================================================
## Instruction for setup (please check the following four steps) 

## Step 1: select the number of resmaples (in our paper, we set it to 500)
n_boot = 500    

## Step 2: select a working directory the same as the location of this file. 
## a) use "setwd()" if necessary. 
## b) If you use RStudio, "Session"- "Set Working Diretory" - "To Source File Location" 

## Step 3: imputation procedure (0 or 50) 
spec = 0

## Step 4: package for quantile regression (please install the package if you have not). 
## install.packages("quantreg")
library("quantreg") 

## miscellaneous setup 
set.seed(12345)  ## seed
k = 6            ## the number of regressors 

for(sid in 1:50){           ## loop for state 
    for(year in 1979:  2012){ ## loop for year 
    
      ##===================================================================
      ## Data    
      ##===================================================================
      ## read data 
      Fname = paste("../data/boot/boot", spec,"/rsample_", year, "_", sid ,".csv",sep="")
      DATA  = read.csv(Fname, header=TRUE, skip=0)
      Nrow  = nrow(DATA)
    
      ## variables 
      mat_set_fin = as.matrix(DATA[,1:94])
      wgt         = as.matrix(DATA$wgt)            ## column: 95
      vecY        = as.matrix(DATA$lnw )           ## column: 96
      matX        = as.matrix(DATA[,97:(97+k-2)])  ## column: 97-(97+k-2) [exclud an intercept]

      ## container for results       
      matRes     = matrix(0, nrow = n_boot, ncol = (2+(k*94)+1) )   ## zero 
      matRes[,1] = rep(year,     times = 1, each = n_boot)          ## 1st: year 
      matRes[,2] = rep(1:n_boot, times = 1, each = 1)               ## 2nd: bootstrap No
      col_end    = ncol(matRes)
      
      ##===================================================================
      ## quantile regression   
      ##===================================================================
      for (b in 1:n_boot) { ## loop for bootstrap 
        
        ## random weight based on exponential distribution (1)
        vecWE = wgt * as.matrix(  rexp(Nrow, rate = 1)  )
        sumWE = as.matrix( sum(vecWE) ) ## sum of random weight 
        
        ## containers 
        temp_vec = matrix(0, nrow = 1, ncol = 0 ) ## empty vector: 1 x 0 
        
        for (Q in 4:97){ ## loop for quantile 
          
          ## setup
          q           = Q / 100
          vec_set_fin = mat_set_fin[,(Q-3)]
          wgt_boot    = vecWE * vec_set_fin
          
          ## quatnile regression 
          qr_fit = rq(vecY ~ matX, tau = q, weights = wgt_boot)
          vecQR  = t( as.matrix(qr_fit$coefficients) ) ## 1 x k
          
          ## save 
          temp_vec = cbind(temp_vec, vecQR) ## adding 1 x k
          
        } ## loop for quantile 
        
        ## save 
        matRes[b,3:(col_end-1)] = temp_vec
        matRes[b,col_end]       = sumWE
        
      } ## loop for bootstrap
      
      ## save result 
      Sname = paste("../data/boot/boot", spec,"/bootstrap_s", sid,"_",year,".csv", sep="")
      write.csv(matRes, file = Sname, row.names=FALSE)
      
  } ## loop for year 
}   ## loop for state 
